summaryrefslogtreecommitdiffstats
path: root/src/prefDVD.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/prefDVD.cpp')
-rw-r--r--src/prefDVD.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/prefDVD.cpp b/src/prefDVD.cpp
index 03c81dd..555c835 100644
--- a/src/prefDVD.cpp
+++ b/src/prefDVD.cpp
@@ -22,11 +22,11 @@
#include "kpushbutton.h"
/*
* Constructs a prefDVD as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-prefDVD::prefDVD( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+prefDVD::prefDVD( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "prefDVD" );
@@ -22,11 +22,11 @@
#include "kpushbutton.h"
/*
- * Constructs a prefDVD as a child of 'tqparent', with the
+ * Constructs a prefDVD as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/